"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthBearer = void 0;
const graphql_1 = require("graphql");
const apollo_server_core_1 = require("apollo-server-core");
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const intercall_1 = require("../intercall");
const auth_type_1 = require("./auth-type");
class AuthBearer {
    constructor(url, fnVerify) {
        this.identityUrl = url;
        this.fnVerify = fnVerify;
        if (!this.identityUrl && !this.fnVerify) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.PARAMETER_MISSING, 'Identity URL is missing', { url, fnVerify });
        }
    }
    static init(url, fnVerify) {
        this.self = new AuthBearer(url, fnVerify);
    }
    async verifyIdToken(authToken) {
        if (undefined === authToken?.info?.token) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.UNAUTHORISED, 'Id token is missing');
        }
        // Call Identity service to verify idToken, check blacklist, and return idToken info (e.g. rules, etc)
        const idToken = this.fnVerify
            ? await this.fnVerify({ token: authToken.info.token, channel: authToken.info.headers?.channel })
            : await (0, intercall_1.callGraphQl)(this.identityUrl, (0, graphql_1.print)((0, apollo_server_core_1.gql) `query PaidChain{ verifyIdToken() }`), 'verifyIdToken', { authorization: authToken.info.token });
        authToken.type = auth_type_1.AuthTokenType.Bearer;
        authToken.grant = true;
        authToken.info.auth = idToken;
        authToken.info.requestedBy = idToken.userId;
        return authToken;
    }
    static get instance() {
        return this.self || (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.NOT_INITIALIZED, 'AuthBearer initialization is required');
    }
}
exports.AuthBearer = AuthBearer;
//# sourceMappingURL=auth-bearer.js.map